import React, { Component } from 'react';
import {CopyToClipboard} from 'react-copy-to-clipboard';
import { Toast } from "antd-mobile"
import {HeaderBar} from '@/common';
import { browser, http, getParam } from '@/utils';
import './index.scss';

class PythonClass extends Component {

  constructor(props) {
    super(props);
    this.state = {
      isWechat: browser.isWeixin,
      isShare: true,
      entryMode: 1, // 0：扫码页，1:落地页，2:直接进入
      isCopy: false,
      command: 'http://m.julyedu.com/python?from=python'
    }
  }

  componentDidMount() {

    this.handleFetchInfo();

    if(getParam('from') === 'barcode') {
      this.setState({
        entryMode: 0
      });
    }
    if(getParam('from') === 'python') {
      this.setState({
        entryMode: 2
      });
    }
  }

  handleFetchInfo = () => {
    const id = getParam(id) || 17;
    http.get(`${API.home}/web/python/share/help/${id}`).then(res => {
      console.log(res);
    })
  }

  handleToSend = () => {
    const { history } = this.props;
    if(browser.isWeixin) {
      this.setState({
        entryMode: 1
      });
      history.push('/python?from=python');
    }else {

    }
    
    console.log(this.props);
  }

  copyToSuccess = () => {
    Toast.info('已复制链接，快去粘贴发给好友吧～');
    this.setState({
      isCopy: true
    });
  }

  render() {
    const { isWechat, isShare, entryMode, command, isCopy } = this.state;
    return (
      <>
        <HeaderBar
          title='Python基础语法'
          arrow={true}
          home={true}
        />
        <PythonContent
          isWechat={isWechat}
          isShare={isShare}
          entryMode={entryMode}
          isCopy={isCopy}
          command={command}
          handleToSend={this.handleToSend}
          copyToSuccess={this.copyToSuccess}
        />
      </>
    );
  }
}

function PythonContent(props) {
  const { isWechat, isShare, entryMode, isCopy, command, handleToSend, copyToSuccess } = props;
  return (
    <div className="python-container">

      {/* 微信 */}
      {
        // (entryMode === 0 && isWechat) && 
        // <div className="python-header">
        //   <p className="python-wechat__title">请点击右上角分享</p>
        //   <i className="iconfont iconyindao"></i>
        // </div>
      }

      {/* 非微信 */}
      {
        // (entryMode === 0 && !isWechat) && 
        // <div className="python-header">
        //   <p className="python-wechat__title">
        //     {isShare? '快分享给好友吧' : '快发给好友求助吧'}
        //   </p>
        // </div>
      }

      {
        (entryMode === 1 && isWechat) && 
        <div className="python-popup">
          <div className="python-header">
            <p className="python-wechat__title">请点击右上角分享</p>
            <i className="iconfont iconyindao"></i>
          </div>
        </div>
      }
      <div className="python-content">
        <div className="python-user">
          <div className="python-user__portrait">
            <img src="" alt=""/>
          </div>
          <h2 className="python-user__id">这里是用户ID</h2>

          {/* 分享 */}
          {
            (entryMode === 0 && isShare) &&
            <p className="python-user__desc">
              完成了
              <span>【练习-听见无脸男的声音】</span>
            </p>
          }
          {
            (entryMode !== 0 && isShare) &&
            <p className="python-user__desc">
              在
              <span>【练习-听见无脸男的声音】</span>完成了<br />
              练习-听见无脸男的声音
            </p>
          }

          {/* 求助 */}
          {
            (entryMode === 0 && !isShare) &&
            <p className="python-user__desc">
              在
              <span>【练习-听见无脸男的声音】</span>
              遇到了困难
            </p>
          }
          {
            (entryMode !== 0 && !isShare) &&
            <p className="python-user__desc">
              在
              <span>【练习-听见无脸男的声音】</span>的<br />
              课程-萌新的进化遇到了困难
            </p>
          }
        </div>
        <h4 className="python-code__title">
          { entryMode !== 0 && isShare? '这是Ta的第723行代码' : '运行结果'}
        </h4>
        <div className="python-code__content">
          code
        </div>
        <h4 className="python-code__title">代码</h4>
        <div className="python-code__content">
          code
          {
            (entryMode !== 1 && isShare) &&
            <button className="python-button python-button__execute">运行看看</button>
          }
        </div>
      </div>

      {
        (entryMode === 0 && isWechat) &&
        <button className="python-button python-button__study" onClick={handleToSend}>发给好友</button>
      }

      {
        (entryMode === 0 && !isWechat && !isCopy) &&
        <CopyToClipboard
          text={command}
          onCopy={copyToSuccess}
        >
          <button className="python-button python-button__study">发给好友</button>
        </CopyToClipboard>
      }

      {
        (entryMode === 0 && !isWechat && isCopy) &&
        <button className="python-button python-button__study">已复制链接，快去粘贴发给好友吧～</button>
      }

      {
        entryMode !== 0 &&
        <button className="python-button python-button__study">我也要学Python</button>
      }
    </div>
  );
}

export default PythonClass;